package test.examples;

import java.awt.Insets;

import javax.swing.JFrame;
import javax.swing.SwingUtilities;

public class MyCoolGame extends JFrame {

	private static final long serialVersionUID = 1L;

	public final int DISPLAY_WIDTH = 300;
	public final int DISPLAY_HEIGHT = 280;

	Board displayArea;

	public MyCoolGame() {
		// Create our board or display area
		displayArea = new Board();

		// attach it to the window
		add(displayArea);

		// set the window title
		setTitle("My Cool Game");

		// ensure that closing the window - closes the application
		setDefaultCloseOperation(EXIT_ON_CLOSE);

		// set the size of our window
		setSize(WIDTH, HEIGHT);

		// center the window in the middle of our screen
		setLocationRelativeTo(null);

		// don't allow users to resize our window
		setResizable(false);

		// show the window
		setVisible(true);
		
		// Adjust the window so that the board has the desired dimensions
		resizeToInternalSize(DISPLAY_WIDTH, DISPLAY_HEIGHT);
		
	}

	private void resizeToInternalSize(int internalWidth, int internalHeight) {
		Insets insets = getInsets();
		final int newWidth = internalWidth + insets.left + insets.right;
		final int newHeight = internalHeight + insets.top + insets.bottom;
		
		Runnable resize = new Runnable() {
			public void run() {
				setSize(newWidth, newHeight);
			}
		};
		
		if (SwingUtilities.isEventDispatchThread()) {
			try {
				SwingUtilities.invokeAndWait(resize);
			} catch (Exception e) {
				// ignore ...but will be no no if using Sonar!
			}
		} else {
			resize.run();
		}
		
		validate();
		
	}

	public void printElementSizes() {
		System.out.println("Window size - width: " + this.getWidth() + " ;height: " + this.getHeight());
		System.out.println("Board size - width: " + displayArea.getWidth() + " ;height: " + displayArea.getHeight());
	}

	public static void main(String[] args) {
		MyCoolGame game = new MyCoolGame();
		game.printElementSizes();
	}
}
